@@ -1,7 +1,7 @@
 # Copyright (C) 2010, 2011 Sebastian Thiel (byronimo@gmail.com) and contributors
 #
 # This module is part of GitDB and is released under
-# the New BSD License: http://www.opensource.org/licenses/bsd-license.php
+# the New BSD License: https://opensource.org/license/bsd-3-clause/
 from gitdb.test.db.lib import (
     TestDBBase,
     with_rw_directory
@@ -32,5 +32,5 @@ class TestLooseDB(TestDBBase):
             assert bin_to_hex(ldb.partial_to_complete_sha_hex(short_sha)) == long_sha
         # END for each sha
 
-        self.failUnlessRaises(BadObject, ldb.partial_to_complete_sha_hex, '0000')
-        # raises if no object could be foudn
+        self.assertRaises(BadObject, ldb.partial_to_complete_sha_hex, '0000')
+        # raises if no object could be found
